@@ -37,7 +37,7 @@ pub mod tty;
 pub mod verb;
 pub mod watcher;
 
-#[cfg(any(target_os = "macos", target_os = "linux"))]
+#[cfg(any(target_os = "macos", target_os = "linux", target_os = "windows"))]
 pub mod filesystems;
 
 #[cfg(unix)]
