@@ -2,9 +2,15 @@ use {
     crate::{
         app::SelectionType,
         content_type,
-        tree::{TreeLine, TreeLineType},
+        tree::{
+            TreeLine,
+            TreeLineType,
+        },
+    },
+    serde::{
+        Deserialize,
+        Serialize,
     },
-    serde::{Deserialize, Serialize},
     std::path::Path,
 };
 
@@ -24,7 +30,10 @@ impl FileTypeCondition {
     pub fn is_default(&self) -> bool {
         self == &Self::default()
     }
-    pub fn accepts_path(self, path: &Path) -> bool {
+    pub fn accepts_path(
+        self,
+        path: &Path,
+    ) -> bool {
         match self {
             Self::Any => true,
             Self::Directory => path.is_dir(),
@@ -37,7 +46,10 @@ impl FileTypeCondition {
             }
         }
     }
-    pub fn accepts_line(self, line: &TreeLine) -> bool {
+    pub fn accepts_line(
+        self,
+        line: &TreeLine,
+    ) -> bool {
         match self {
             Self::Any => true,
             Self::Directory => line.is_dir(),
